from .spark import Spark

__version__ = '0.0.1'
__license__ = 'MIT'
__author__ = 'Kevin Walchko'
__doc__ = u"""
Draw bar graphs from input data. By default, it draws a vertical bar
chart, but you can also draw a horizontal bar chart if you want.
"""



from __future__ import print_function, division
import sys

# in py3, unichr doesn't exist, so we will just alias it to chr
if int(sys.version[0]) > 2:
    unichr = chr

class Spark(object):
    def __init__(self):
        """
        """
        self.vbars = [' '] + [unichr(int(0x2581 + i)) for i in range(8)]
        tmp = [unichr(int(0x2588 + i)) for i in range(8)]
        tmp.reverse()
        self.hbars = [' '] + tmp

    def dump(self):
        print('vbar')
        for i, b in enumerate(self.vbars):
            print(i, b)
        print('hbar')
        for i, b in enumerate(self.hbars):
            print(i, b)

    def scale(self, data, mx_val=8):
        """
        Scale the data between integer values 0-8
        """
        mx = max(data)
        mn = min(data)
        k = mx_val/(mx-mn)
        b = -k*mn

        ret = [int(k*d+b) for d in data]
        return ret,mx,mn

    def bar(self, data, blocks):
        """
        Draw bar, given the data and block arrays
        """
        ret = []
        data ,_,_= self.scale(data, len(blocks)-1)
        for d in data:
            ret.append(blocks[d])
        return u''.join(ret)

    def vbar(self, data):
        return self.bar(data, self.vbars)

    def hbar(self, data):
        return self.bar(data, self.hbars)



#!/usr/bin/env python

from __future__ import print_function, division
import spark
import argparse

parser = argparse.ArgumentParser(
    description=spark.__doc__.encode('utf-8'),
    # formatter_class=argparse.RawDescriptionHelpFormatter
    )
parser.add_argument("data",nargs=argparse.REMAINDER,help="Input data to plot")
parser.add_argument("--horizontal", "-r", action="store_true", help="Draw horizontal bars")
parser.add_argument("--version", "-v", action="store_true", help="Prints version number and exits")

args = parser.parse_args()

if args.version:
    print(spark.__version__)
    exit(0)

sp = spark.Spark()

try:
    for i, d in enumerate(args.data):
        args.data[i] = float(d)
except Exception as e:
    print('ERROR on input data:', e)
    exit(1)

# print(args.data)

if args.horizontal:
    print(sp.hbar(args.data))
else:
    print(sp.vbar(args.data))



from __future__ import print_function
from setuptools import setup
from yasl import __version__ as VERSION
from build_utils import BuildCommand
from build_utils import PublishCommand
from build_utils import BinaryDistribution


PACKAGE_NAME = 'yasl'
BuildCommand.pkg = PACKAGE_NAME
PublishCommand.pkg = PACKAGE_NAME
PublishCommand.version = VERSION


setup(
	author='Kevin Walchko',
	author_email='walchko@users.noreply.github.com',
	name=PACKAGE_NAME,
	version=VERSION,
	description='Yet another sparkline program/library',
	long_description=open('readme.rst').read(),
	url='http://github.com/walchko/{}'.format(PACKAGE_NAME),
	classifiers=[
		'Development Status :: 4 - Beta',
		'Intended Audience :: Developers',
		'License :: OSI Approved :: MIT License',
		'Operating System :: OS Independent',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3.6',
		'Topic :: Software Development :: Libraries',
		'Topic :: Software Development :: Libraries :: Python Modules',
		'Topic :: Software Development :: Libraries :: Application Frameworks'
	],
	license='MIT',
	keywords=['sparkline', 'spark', '', 'bar', 'graph', 'plot'],
	packages=[PACKAGE_NAME],
	install_requires=['build_utils'],
	cmdclass={
		'make': BuildCommand,
		'publish': PublishCommand
	}
)
